@@ -1,10 +1,12 @@
 #![allow(
     clippy::cast_sign_loss,
     clippy::default_trait_access,
+    clippy::derive_partial_eq_without_eq,
     clippy::doc_markdown,
     clippy::enum_glob_use,
     clippy::if_same_then_else,
     clippy::inherent_to_string,
+    clippy::into_iter_without_iter,
     clippy::items_after_statements,
     clippy::large_enum_variant,
     clippy::match_bool,
@@ -20,16 +22,16 @@
     clippy::similar_names,
     clippy::single_match,
     clippy::single_match_else,
+    clippy::struct_field_names,
     clippy::too_many_arguments,
     clippy::too_many_lines,
     clippy::toplevel_ref_arg,
+    clippy::uninlined_format_args,
     clippy::useless_let_if_seq,
     // clippy bug: https://github.com/rust-lang/rust-clippy/issues/6983
     clippy::wrong_self_convention
 )]
 
-extern crate proc_macro;
-
 mod derive;
 mod expand;
 mod generics;
@@ -37,9 +39,9 @@ mod syntax;
 mod tokens;
 mod type_id;
 
-#[cfg(feature = "experimental")]
+#[cfg(feature = "experimental-enum-variants-from-header")]
 mod clang;
-#[cfg(feature = "experimental")]
+#[cfg(feature = "experimental-enum-variants-from-header")]
 mod load;
 
 use crate::syntax::file::Module;
