@@ -1,5 +1,6 @@
 use crate::clang::{Clang, Node};
 use crate::syntax::attrs::OtherAttrs;
+use crate::syntax::cfg::CfgExpr;
 use crate::syntax::namespace::Namespace;
 use crate::syntax::report::Errors;
 use crate::syntax::{Api, Discriminant, Doc, Enum, EnumRepr, ForeignName, Pair, Variant};
@@ -17,7 +18,7 @@ use syn::{parse_quote, Path};
 
 const CXX_CLANG_AST: &str = "CXX_CLANG_AST";
 
-pub fn load(cx: &mut Errors, apis: &mut [Api]) {
+pub(crate) fn load(cx: &mut Errors, apis: &mut [Api]) {
     let ref mut variants_from_header = Vec::new();
     for api in apis {
         if let Api::Enum(enm) = api {
@@ -35,7 +36,7 @@ pub fn load(cx: &mut Errors, apis: &mut [Api]) {
         }
     }
 
-    let span = match variants_from_header.get(0) {
+    let span = match variants_from_header.first() {
         None => return,
         Some(enm) => enm.variants_from_header_attr.clone().unwrap(),
     };
@@ -58,10 +59,10 @@ pub fn load(cx: &mut Errors, apis: &mut [Api]) {
             let is_gzipped = memmap.get(..2) == Some(b"\x1f\x8b");
             if is_gzipped {
                 gunzipped = Vec::new();
-                let decode_result = GzDecoder::new(&mut gunzipped).write_all(&memmap);
-                decode_result.map(|_| gunzipped.as_slice())
+                let decode_result = GzDecoder::new(&mut gunzipped).write_all(memmap);
+                decode_result.map(|()| gunzipped.as_slice())
             } else {
-                Ok(&memmap as &[u8])
+                Ok(memmap as &[u8])
             }
         }
         Err(error) => Err(error),
@@ -142,7 +143,7 @@ fn traverse<'a>(
                     };
                     let repr = translate_qual_type(
                         cx,
-                        &enm,
+                        enm,
                         fixed_underlying_type
                             .desugared_qual_type
                             .as_ref()
@@ -164,7 +165,7 @@ fn traverse<'a>(
                     .variants_from_header_attr
                     .as_ref()
                     .unwrap()
-                    .path
+                    .path()
                     .get_ident()
                     .unwrap()
                     .span();
@@ -207,6 +208,7 @@ fn traverse<'a>(
                     }
                 };
                 enm.variants.push(Variant {
+                    cfg: CfgExpr::Unconditional,
                     doc: Doc::new(),
                     attrs: OtherAttrs::none(),
                     name: Pair {
@@ -257,12 +259,12 @@ fn translate_qual_type(cx: &mut Errors, enm: &Enum, qual_type: &str) -> Path {
         .variants_from_header_attr
         .as_ref()
         .unwrap()
-        .path
+        .path()
         .get_ident()
         .unwrap()
         .span();
     let ident = Ident::new(rust_std_name, span);
-    let path = quote_spanned!(span=> ::std::os::raw::#ident);
+    let path = quote_spanned!(span=> ::cxx::core::ffi::#ident);
     parse_quote!(#path)
 }
 
@@ -275,7 +277,7 @@ enum ParsedDiscriminant {
 fn discriminant_value(mut clang: &[Node]) -> ParsedDiscriminant {
     if clang.is_empty() {
         // No discriminant expression provided; use successor of previous
-        // descriminant.
+        // discriminant.
         return ParsedDiscriminant::Successor;
     }
 
@@ -299,7 +301,7 @@ fn discriminant_value(mut clang: &[Node]) -> ParsedDiscriminant {
 fn span_for_enum_error(enm: &Enum) -> TokenStream {
     let enum_token = enm.enum_token;
     let mut brace_token = Group::new(Delimiter::Brace, TokenStream::new());
-    brace_token.set_span(enm.brace_token.span);
+    brace_token.set_span(enm.brace_token.span.join());
     quote!(#enum_token #brace_token)
 }
 
